:orphan:
   
fsleyes_widgets.placeholder_textctrl module
===========================================

.. automodule:: fsleyes_widgets.placeholder_textctrl
    :members:
    :undoc-members:
    :show-inheritance:
